@@ -1,25 +1,28 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Any, Dict, Optional
+from typing import Any, Dict
 
 import requests
 import hashlib
 import hmac
+import logging
 
 
 @dataclass
 class ApiClient:
     """ Objeto para definir ApiClient """
 
-    api_url: Optional[str] = None
-    api_key: Optional[str] = None
-    api_secret: Optional[str] = None
+    api_url: str = "https://sandbox.flow.cl/api"
+    api_key: str = ""
+    api_secret: str = ""
 
     def make_signature(self, params: Dict[str, Any]) -> str:
         string = ""
         for k, d in params.items():
-            string = string + f"{k}{d}"
+            if d is not None:
+                string = string + f"{k}{d}"
+        logging.debug(f"String to Hash: {string}")
         hash_string = hmac.new(
             self.api_secret.encode(), string.encode(), hashlib.sha256
         ).hexdigest()
@@ -28,3 +31,9 @@ class ApiClient:
 
     def get(self, url: str, query_string: Dict[str, Any]) -> Dict[str, Any]:
         return requests.get(url, params=query_string)
+
+    def post(self, url: str, post_data: Dict[str, Any]) -> Dict[str, Any]:
+        return requests.post(url, data=post_data)
+
+    def put(self, url: str, put_data: Dict[str, Any]) -> Dict[str, Any]:
+        return requests.put(url, data=put_data)
